@@ -1,10 +1,6 @@
-import abc
-from sqlite3 import Connection
-
 from tileset_analyzer.data_source.folder_tiles.folder_tiles_source import FolderTilesSource
 from tileset_analyzer.data_source.mbtiles.mbtiles_source import MBTilesSource
 from tileset_analyzer.entities.job_param import JobParam, TileSourceType
-import os
 
 
 class TilesetSourceFactory:
